@@ -36,7 +36,6 @@ import time
 from urllib import urlencode
 from urlparse import urljoin
 import webbrowser
-import ConfigParser
 from base64 import (
     b64decode,
     b64encode,
@@ -85,10 +84,6 @@ class Credentials(OAuthAuthorizer):
         sio = StringIO()
         self.save(sio)
         serialized = sio.getvalue()
-        # Some users have reported problems with corrupted keyrings, both in
-        # Gnome and KDE, when newlines are included in the password.  Avoid
-        # this problem by base 64 encoding the serialized value.
-        serialized = b64encode(serialized)
         return serialized
 
     @classmethod
@@ -98,8 +93,6 @@ class Credentials(OAuthAuthorizer):
         This should probably be moved into OAuthAuthorizer.
         """
         credentials = cls()
-        if 'consumer_key' not in value:
-            value = b64decode(value)
         credentials.load(StringIO(value))
         return credentials
 
@@ -178,7 +171,7 @@ class Credentials(OAuthAuthorizer):
             oauth_token=self._request_token.key,
             oauth_signature='&%s' % self._request_token.secret)
         url = web_root + access_token_page
-        headers = {'Referer' : web_root}
+        headers = {'Referer': web_root}
         response, content = httplib2.Http().request(
             url, method='POST', headers=headers, body=urlencode(params))
         if response.status != 200:
@@ -308,6 +301,8 @@ class KeyringCredentialStore(CredentialStore):
     integrating third-party websites into Launchpad.
     """
 
+    B64MARKER = "<B64>"
+
     @staticmethod
     def _ensure_keyring_imported():
         """Ensure the keyring module is imported (postponing side effects).
@@ -325,6 +320,10 @@ class KeyringCredentialStore(CredentialStore):
         """Store newly-authorized credentials in the keyring."""
         self._ensure_keyring_imported()
         serialized = credentials.serialize()
+        # Some users have reported problems with corrupted keyrings, both in
+        # Gnome and KDE, when newlines are included in the password.  Avoid
+        # this problem by base 64 encoding the serialized value.
+        serialized = self.B64MARKER + b64encode(serialized)
         keyring.set_password(
             'launchpadlib', unique_key, serialized)
 
@@ -335,10 +334,21 @@ class KeyringCredentialStore(CredentialStore):
             'launchpadlib', unique_key)
         if credential_string is not None:
             credential_string = credential_string.encode('utf8')
+            if credential_string.startswith(self.B64MARKER):
+                try:
+                    credential_string = b64decode(
+                        credential_string[len(self.B64MARKER):])
+                except TypeError:
+                    # The credential_string should be base 64 but cannot be
+                    # decoded.
+                    return None
             try:
                 credentials = Credentials.from_string(credential_string)
                 return credentials
-            except ConfigParser.NoOptionError:
+            except:
+                # If any error occurs at this point the most reasonable thing
+                # to do is return no credentials, which will require
+                # re-authorization but the user will be able to proceed.
                 return None
         return None
 
