@@ -590,9 +590,11 @@ class Launchpad(ServiceRoot):
             (service_root_uri, launchpadlib_dir, cache_dir, service_root_dir)
         """
         if launchpadlib_dir is None:
-            home_dir = os.environ['HOME']
-            launchpadlib_dir = os.path.join(home_dir, '.launchpadlib')
+            launchpadlib_dir = os.path.join('~', '.launchpadlib')
         launchpadlib_dir = os.path.expanduser(launchpadlib_dir)
+        if launchpadlib_dir[:1] == '~':
+            raise ValueError("Must set $HOME or pass 'launchpadlib_dir' to "
+                "indicate location to store cached data")
         if not os.path.exists(launchpadlib_dir):
             os.makedirs(launchpadlib_dir, 0700)
         os.chmod(launchpadlib_dir, 0700)
@@ -606,4 +608,3 @@ class Launchpad(ServiceRoot):
         if not os.path.exists(cache_path):
             os.makedirs(cache_path, 0700)
         return (service_root, launchpadlib_dir, cache_path, service_root_dir)
-
